### Name: IBGEtabula
### Title: Estimao de totais com CV por mltiplos domnios
### Aliases: IBGEtabula


### ** Examples

library(survey)
library(IBGEPesq)

data(ocupacao2005)
colnames(dados) <- c("UF", "IDADE", "SEXO", "ANOS_ESTUDO", "COND_ATIVIDADE",
 "COND_OCUPACAO", "PREVIDENCIA", "SINDICATO", "ATIVIDADE", "OCUPACAO", "PESOS",
 "gr.anos", "ESP_DOM", "NUM_MOR", "PROJECAO", "INV_FRA", "STRAT", "PSU", "SUBA")

dados <- dados[,c("UF", "SEXO", "COND_OCUPACAO", "PESOS", "gr.anos",
               "PROJECAO", "INV_FRA", "STRAT", "PSU", "SUBA")]
dados <- transform(dados,
        pestrato = PROJECAO,
        pesos = INV_FRA * SUBA,
        brasil = rep(1,nrow(dados)),
  norte = (trunc(UF/10) %in% 1)*1,
  nordeste = (trunc(UF/10) %in% 2)*1,
  sudeste = (trunc(UF/10) %in% 3)*1,
  sul = (trunc(UF/10) %in% 4)*1,
  centroeste = (trunc(UF/10) %in% 5)*1)
  
dados <- transform(dados, pestrato=factor(pestrato),
                   gr.anos=factor(gr.anos,labels=c("Menos de 1 ano",
                  "1 a 3 anos", "4 a 7 anos", "8 a 10 anos",
                  "11 anos ou mais", "SD")),
                  SEXO = factor(SEXO, labels=c("Homens", "Mulheres")),
                  COND_OCUPACAO = factor(COND_OCUPACAO, labels=c("Ocupados",
                  "Desocupados", "SD"), exclude=NULL))

levels(dados$pestrato)<-1:length(levels(dados$pestrato))
pos.estratos <- data.frame(pestrato=levels(dados$pestrato),
        Freq=sort(unique(dados$PROJECAO)))

options(survey.lonely.psu="average", survey.ultimate.cluster=T)
dpnad<-svydesign(ids=~PSU, strata=~STRAT, data=dados, nest=TRUE,
        weights=~pesos)
dpnad<-postStratify(dpnad, ~pestrato, pos.estratos) #ps - estratificao

colunas <- c("brasil","norte","nordeste","sudeste","sul","centroeste")
grupos <- c("COND_OCUPACAO","SEXO","gr.anos")
elimina <- list("SD", NA, "SD")

estimativa <- IBGEtabula(dpnad, colunas, grupos, elimina, total.geral=T)



